summaryrefslogtreecommitdiffstats
path: root/dist/mv3/firefox/publish-signed-beta.py
diff options
context:
space:
mode:
Diffstat (limited to 'dist/mv3/firefox/publish-signed-beta.py')
-rwxr-xr-xdist/mv3/firefox/publish-signed-beta.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/dist/mv3/firefox/publish-signed-beta.py b/dist/mv3/firefox/publish-signed-beta.py
index 0c5f8cd..f298cc8 100755
--- a/dist/mv3/firefox/publish-signed-beta.py
+++ b/dist/mv3/firefox/publish-signed-beta.py
@@ -64,9 +64,9 @@ github_owner = 'gorhill'
github_repo = 'uBlock'
# Load/save auth secrets
# The build directory is excluded from git
ubo_secrets = dict()
-ubo_secrets_filename = os.path.join(projdir, 'dist', 'build', 'ubo_secrets')
+ubo_secrets_filename = os.path.join(projdir, 'tmp', 'ubo_secrets')
if os.path.isfile(ubo_secrets_filename):
with open(ubo_secrets_filename) as f:
ubo_secrets = json.load(f)
@@ -64,9 +64,9 @@ github_owner = 'gorhill'
github_repo = 'uBlock'
# Load/save auth secrets
-# The build directory is excluded from git
+# The tmp directory is excluded from git
ubo_secrets = dict()